@@ -1,4 +1,4 @@
-﻿define(['dialogHelper', 'jQuery', 'paper-item', 'emby-input', 'emby-button', 'paper-item-body', 'paper-icon-button-light', 'css!./directorybrowser'], function (dialogHelper, $) {
+﻿define(['dialogHelper', 'jQuery', 'listViewStyle', 'emby-input', 'emby-button', 'paper-icon-button-light', 'css!./directorybrowser'], function (dialogHelper, $) {
 
     var systemInfo;
     function getSystemInfo() {
@@ -91,12 +91,14 @@
     function getItem(cssClass, type, path, name) {
 
         var html = '';
-        html += '<paper-item role="menuitem" class="' + cssClass + '" data-type="' + type + '" data-path="' + path + '">';
-        html += '<paper-item-body>';
+        html += '<div class="listItem ' + cssClass + '" data-type="' + type + '" data-path="' + path + '" style="border-bottom:1px solid #e0e0e0;">';
+        html += '<div class="listItemBody" style="min-height:2em;padding-left:0;">';
+        html += '<div class="listItemBodyText">';
         html += name;
-        html += '</paper-item-body>';
-        html += '<iron-icon icon="arrow-forward"></iron-icon>';
-        html += '</paper-item>';
+        html += '</div>';
+        html += '</div>';
+        html += '<i class="md-icon" style="font-size:inherit;">arrow_forward</i>';
+        html += '</div>';
 
         return html;
     }
@@ -137,7 +139,7 @@
         html += '<div style="flex-grow:1;">';
         html += '<input is="emby-input" id="txtDirectoryPickerPath" type="text" required="required" label="' + Globalize.translate('LabelCurrentPath') + '"/>';
         html += '</div>';
-        html += '<button type="button" is="paper-icon-button-light" class="btnRefreshDirectories" title="' + Globalize.translate('ButtonRefresh') + '"><iron-icon icon="refresh"></iron-icon></button>';
+        html += '<button type="button" is="paper-icon-button-light" class="btnRefreshDirectories" title="' + Globalize.translate('ButtonRefresh') + '"><i class="md-icon">search</i></button>';
         html += '</div>';
 
         html += '<div class="results paperList" style="height: 180px; overflow-y: auto;"></div>';
