@@ -194,7 +194,7 @@
 
             // This should be outside of the IF
             // But for now, if you change songs but keep the same artist, the backdrop will flicker because in-between songs it clears out the image
-            if (!browser.mobile) {
+            if (!browser.slow) {
                 // Exclude from mobile because it just doesn't perform well
                 require(['backdrop'], function (backdrop) {
                     backdrop.setBackdrop(backdropUrl);
