@@ -1,4 +1,4 @@
-﻿(function () {
+﻿define(['events'], function (events) {
 
     function transferPlayback(oldPlayer) {
 
@@ -25,7 +25,7 @@
         });
     }
 
-    Events.on(MediaController, 'playerchange', function (e, newPlayer, newTarget, oldPlayer) {
+    events.on(MediaController, 'playerchange', function (e, newPlayer, newTarget, oldPlayer) {
 
         if (!oldPlayer) {
             console.log('Skipping remote control autoplay because oldPlayer is null');
@@ -48,4 +48,4 @@
         }
     });
 
-})();
\ No newline at end of file
+});
\ No newline at end of file
