@@ -1,4 +1,4 @@
-﻿define(['datetime'], function (datetime) {
+﻿define(['datetime', 'jQuery', 'cardStyle'], function (datetime, $) {
 
     function renderNoHealthAlertsMessage(page) {
 
@@ -151,28 +151,28 @@
                     var itemHtml = '';
 
                     itemHtml += '<a class="clearLink" href="' + item.Link + '" target="_blank">';
-                    itemHtml += '<paper-icon-item>';
+                    itemHtml += '<div class="listItem">';
 
-                    itemHtml += '<paper-fab mini class="blue" icon="dvr" item-icon></paper-fab>';
+                    itemHtml += '<i class="listItemIcon md-icon">dvr</i>';
 
-                    itemHtml += '<paper-item-body three-line>';
+                    itemHtml += '<div class="listItemBody three-line">';
 
-                    itemHtml += '<div>';
+                    itemHtml += '<h3 class="listItemBodyText">';
                     itemHtml += item.Title;
-                    itemHtml += '</div>';
+                    itemHtml += '</h3>';
 
-                    itemHtml += '<div secondary>';
+                    itemHtml += '<div class="listItemBodyText secondary">';
                     var date = datetime.parseISO8601Date(item.Date, true);
                     itemHtml += date.toLocaleDateString();
                     itemHtml += '</div>';
 
-                    itemHtml += '<div secondary>';
+                    itemHtml += '<div class="listItemBodyText secondary listItemBodyText-nowrap">';
                     itemHtml += item.Description;
                     itemHtml += '</div>';
 
-                    itemHtml += '</paper-item-body>';
+                    itemHtml += '</div>';
 
-                    itemHtml += '</paper-icon-item>';
+                    itemHtml += '</div>';
                     itemHtml += '</a>';
 
                     return itemHtml;
@@ -309,7 +309,7 @@
 
                 var nowPlayingItem = session.NowPlayingItem;
 
-                var className = nowPlayingItem ? 'card activeSession' : 'card activeSession';
+                var className = nowPlayingItem ? 'scalableCard card activeSession' : 'scalableCard card activeSession';
 
                 if (session.TranscodingInfo && session.TranscodingInfo.CompletionPercentage) {
                     className += ' transcodingSession';
@@ -317,7 +317,7 @@
 
                 html += '<div class="' + className + '" id="' + rowId + '">';
 
-                html += '<div class="cardBox" style="box-shadow:0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12), 0 3px 1px -2px rgba(0, 0, 0, 0.2);margin:4px;">';
+                html += '<div class="cardBox visualCardBox">';
                 html += '<div class="cardScalable">';
 
                 html += '<div class="cardPadder"></div>';
@@ -352,8 +352,6 @@
 
                 html += '<div class="sessionNowPlayingTime">' + DashboardPage.getSessionNowPlayingTime(session) + '</div>';
 
-                html += '<div class="sessionNowPlayingStreamInfo">' + DashboardPage.getSessionNowPlayingStreamInfo(session) + '</div>';
-
                 //if (session.TranscodingInfo && session.TranscodingInfo.Framerate) {
 
                 //    html += '<div class="sessionTranscodingFramerate">' + session.TranscodingInfo.Framerate + ' fps</div>';
@@ -372,16 +370,16 @@
                     var position = session.PlayState.PositionTicks || 0;
                     var value = (100 * position) / nowPlayingItem.RunTimeTicks;
 
-                    html += '<progress class="itemProgressBar playbackProgress" min="0" max="100" value="' + value + '"></progress>';
+                    html += '<progress class="playbackProgress" min="0" max="100" value="' + value + '"></progress>';
                 } else {
-                    html += '<progress class="itemProgressBar playbackProgress" min="0" max="100" style="display:none;"></progress>';
+                    html += '<progress class="playbackProgress" min="0" max="100" style="display:none;"></progress>';
                 }
 
                 if (session.TranscodingInfo && session.TranscodingInfo.CompletionPercentage) {
 
-                    html += '<progress class="itemProgressBar transcodingProgress" min="0" max="100" value="' + session.TranscodingInfo.CompletionPercentage.toFixed(1) + '"></progress>';
+                    html += '<progress class="transcodingProgress" min="0" max="100" value="' + session.TranscodingInfo.CompletionPercentage.toFixed(1) + '"></progress>';
                 } else {
-                    html += '<progress class="itemProgressBar transcodingProgress" min="0" max="100" style="display:none;"></progress>';
+                    html += '<progress class="transcodingProgress" min="0" max="100" style="display:none;"></progress>';
                 }
 
                 html += '</div>';
@@ -391,8 +389,13 @@
                 // cardScalable
                 html += '</div>';
 
-                html += '<div style="padding:1em;border-top:1px solid #eee;background:#fff;text-align:center;text-transform:uppercase;display:flex;align-items:center;justify-content:center;">';
+                html += '<div style="padding:1em;border-top:1px solid #eee;background:#fff;text-align:center;">';
 
+                html += '<div class="sessionNowPlayingStreamInfo" style="padding:0 0 1em;">';
+                html += DashboardPage.getSessionNowPlayingStreamInfo(session);
+                html += '</div>';
+
+                html += '<div style="display:flex;align-items:center;justify-content:center;text-transform:uppercase;">';
                 var userImage = DashboardPage.getUserImage(session);
                 if (userImage) {
                     html += '<img style="border-radius:50px;margin-right:.5em;" src="' + userImage + '" />';
@@ -404,6 +407,7 @@
                 html += DashboardPage.getUsersHtml(session) || '&nbsp;';
                 html += '</div>';
                 html += '</div>';
+                html += '</div>';
 
                 // cardBox
                 html += '</div>';
@@ -422,17 +426,22 @@
             var html = '';
 
             //html += '<div>';
+            var showTranscodingInfo = false;
 
             if (session.TranscodingInfo && session.TranscodingInfo.IsAudioDirect && session.TranscodingInfo.IsVideoDirect) {
                 html += Globalize.translate('LabelPlayMethodDirectStream');
             }
+            else if (session.TranscodingInfo && session.TranscodingInfo.IsVideoDirect) {
+                html += Globalize.translate('LabelPlayMethodDirectStream');
+            }
             else if (session.PlayState.PlayMethod == 'Transcode') {
                 html += Globalize.translate('LabelPlayMethodTranscoding');
 
                 if (session.TranscodingInfo && session.TranscodingInfo.Framerate) {
 
-                    html += ' - ' + session.TranscodingInfo.Framerate + ' fps';
+                    html += ' (' + session.TranscodingInfo.Framerate + ' fps' + ')';
                 }
+                showTranscodingInfo = true;
             }
             else if (session.PlayState.PlayMethod == 'DirectStream') {
                 html += Globalize.translate('LabelPlayMethodDirectPlay');
@@ -443,41 +452,44 @@
 
             //html += '</div>';
 
-            //if (session.TranscodingInfo) {
+            if (showTranscodingInfo) {
 
-            //    html += '<br/>';
+                var line = [];
 
-            //    var line = [];
+                if (session.TranscodingInfo) {
+                    if (session.TranscodingInfo.Bitrate) {
 
-            //    if (session.TranscodingInfo.Container) {
+                        if (session.TranscodingInfo.Bitrate > 1000000) {
+                            line.push((session.TranscodingInfo.Bitrate / 1000000).toFixed(1) + ' Mbps');
+                        } else {
+                            line.push(Math.floor(session.TranscodingInfo.Bitrate / 1000) + ' kbps');
+                        }
+                    }
+                    if (session.TranscodingInfo.Container) {
 
-            //        line.push(session.TranscodingInfo.Container);
-            //    }
-            //    if (session.TranscodingInfo.Bitrate) {
+                        line.push(session.TranscodingInfo.Container);
+                    }
 
-            //        if (session.TranscodingInfo.Bitrate > 1000000) {
-            //            line.push((session.TranscodingInfo.Bitrate / 1000000).toFixed(1) + ' Mbps');
-            //        } else {
-            //            line.push(Math.floor(session.TranscodingInfo.Bitrate / 1000) + ' kbps');
-            //        }
-            //    }
-            //    if (line.length) {
+                    if (session.TranscodingInfo.VideoCodec) {
 
-            //        html += '<div>' + line.join(' ') + '</div>';
-            //    }
+                        //line.push(Globalize.translate('LabelVideoCodec').replace('{0}', session.TranscodingInfo.VideoCodec));
+                        line.push(session.TranscodingInfo.VideoCodec);
+                    }
+                    if (session.TranscodingInfo.AudioCodec && session.TranscodingInfo.AudioCodec != session.TranscodingInfo.Container) {
 
-            //    if (session.TranscodingInfo.VideoCodec) {
+                        //line.push(Globalize.translate('LabelAudioCodec').replace('{0}', session.TranscodingInfo.AudioCodec));
+                        line.push(session.TranscodingInfo.AudioCodec);
+                    }
+                }
 
-            //        html += '<div>' + Globalize.translate('LabelVideoCodec').replace('{0}', session.TranscodingInfo.VideoCodec) + '</div>';
-            //    }
-            //    if (session.TranscodingInfo.AudioCodec && session.TranscodingInfo.AudioCodec != session.TranscodingInfo.Container) {
+                if (line.length) {
 
-            //        html += '<div>' + Globalize.translate('LabelAudioCodec').replace('{0}', session.TranscodingInfo.AudioCodec) + '</div>';
-            //    }
+                    html += ' - ' + line.join(' ');
+                }
 
-            //}
+            }
 
-            return html;
+            return html || '&nbsp;';
         },
 
         getSessionNowPlayingTime: function (session) {
@@ -779,7 +791,7 @@
 
                     html += "<span style='color:#009F00;margin-left:5px;margin-right:5px;'>" + progress + "%</span>";
 
-                    html += '<button type="button" is="paper-icon-button-light" title="' + Globalize.translate('ButtonStop') + '" onclick="DashboardPage.stopTask(\'' + task.Id + '\');"><iron-icon icon="cancel"></iron-icon></button>';
+                    html += '<button type="button" is="paper-icon-button-light" title="' + Globalize.translate('ButtonStop') + '" onclick="DashboardPage.stopTask(\'' + task.Id + '\');" class="autoSize"><i class="md-icon">cancel</i></button>';
                 }
                 else if (task.State == "Cancelling") {
                     html += '<span style="color:#cc0000;">' + Globalize.translate('LabelStopping') + '</span>';
@@ -819,21 +831,22 @@
 
             var imgUrl, text;
 
+            var supporterIconContainer = page.querySelector('.supporterIconContainer');
+
             if (!AppInfo.enableSupporterMembership) {
-                $('.supporterIconContainer', page).remove();
+                supporterIconContainer.classList.add('hide');
             }
             else if (pluginSecurityInfo.IsMBSupporter) {
 
+                supporterIconContainer.classList.remove('hide');
+
                 imgUrl = "css/images/supporter/supporterbadge.png";
                 text = Globalize.translate('MessageThankYouForSupporting');
 
-                $('.supporterIconContainer', page).html('<a class="imageLink supporterIcon" href="http://emby.media/premiere" target="_blank" title="' + text + '"><img src="' + imgUrl + '" style="height:32px;vertical-align: middle; margin-right: .5em;" /></a><span style="position:relative;top:2px;text-decoration:none;">' + text + '</span>');
+                supporterIconContainer.innerHTML = '<a class="imageLink supporterIcon" href="http://emby.media/premiere" target="_blank" title="' + text + '"><img src="' + imgUrl + '" style="height:32px;vertical-align: middle; margin-right: .5em;" /></a><span style="position:relative;top:2px;text-decoration:none;">' + text + '</span>';
             } else {
 
-                imgUrl = "css/images/supporter/nonsupporterbadge.png";
-                text = Globalize.translate('MessagePleaseSupportProject');
-
-                $('.supporterIconContainer', page).html('<a class="imageLink supporterIcon" href="http://emby.media/premiere" target="_blank" title="' + text + '"><img src="' + imgUrl + '" style="height:32px;vertical-align: middle; margin-right: .5em;" /><span style="position:relative;top:2px;text-decoration:none;">' + text + '</span></a>');
+                supporterIconContainer.classList.add('hide');
             }
         },
 
@@ -1021,7 +1034,7 @@
 
             var html = '';
 
-            html += '<paper-icon-item>';
+            html += '<div class="listItem">';
 
             var color = entry.Severity == 'Error' || entry.Severity == 'Fatal' || entry.Severity == 'Warn' ? '#cc0000' : '#52B54B';
 
@@ -1033,30 +1046,30 @@
                     height: 40
                 });
 
-                html += '<paper-fab mini style="background-color:' + color + ';background-image:url(\'' + userImgUrl + '\');background-repeat:no-repeat;background-position:center center;background-size: cover;" item-icon></paper-fab>';
+                html += '<i class="listItemIcon md-icon" style="width:2em!important;height:2em!important;padding:0;color:transparent;background-color:' + color + ';background-image:url(\'' + userImgUrl + '\');background-repeat:no-repeat;background-position:center center;background-size: cover;">dvr</i>';
             }
             else {
-                html += '<paper-fab mini icon="dvr" style="background-color:' + color + '" item-icon></paper-fab>';
+                html += '<i class="listItemIcon md-icon" style="background-color:' + color + '">dvr</i>';
             }
 
-            html += '<paper-item-body three-line>';
+            html += '<div class="listItemBody three-line">';
 
-            html += '<div>';
+            html += '<h3 class="listItemBodyText">';
             html += entry.Name;
-            html += '</div>';
+            html += '</h3>';
 
-            html += '<div secondary>';
+            html += '<div class="listItemBodyText secondary">';
             var date = datetime.parseISO8601Date(entry.Date, true);
             html += date.toLocaleDateString() + ' ' + date.toLocaleTimeString().toLowerCase();
             html += '</div>';
 
-            html += '<div secondary>';
+            html += '<div class="listItemBodyText secondary listItemBodyText-nowrap">';
             html += entry.ShortOverview || '';
             html += '</div>';
 
-            html += '</paper-item-body>';
+            html += '</div>';
 
-            html += '</paper-icon-item>';
+            html += '</div>';
 
             return html;
         }
@@ -1313,29 +1326,24 @@
 
     })(jQuery, document, window);
 
-    (function () {
+    pageClassOn('pageshow', "type-interior", function () {
 
-        $(document).on('pageshow', ".type-interior", function () {
+        var page = this;
 
-            var page = this;
+        Dashboard.getPluginSecurityInfo().then(function (pluginSecurityInfo) {
 
-            Dashboard.getPluginSecurityInfo().then(function (pluginSecurityInfo) {
+            if (!page.querySelector('.customSupporterPromotion')) {
 
-                if (!$('.customSupporterPromotion', page).length) {
-                    $('.supporterPromotion', page).remove();
+                $('.supporterPromotion', page).remove();
 
-                    if (!pluginSecurityInfo.IsMBSupporter && AppInfo.enableSupporterMembership) {
+                if (!pluginSecurityInfo.IsMBSupporter && AppInfo.enableSupporterMembership) {
 
-                        var html = '<div class="supporterPromotion"><a class="clearLink" href="http://emby.media/premiere" target="_blank"><paper-button raised class="block" style="text-transform:none;background-color:#52B54B;color:#fff;"><div>' + Globalize.translate('HeaderSupportTheTeam') + '</div><div style="font-weight:normal;margin-top:5px;">' + Globalize.translate('TextEnjoyBonusFeatures') + '</div></paper-button></a></div>';
+                    var html = '<div class="supporterPromotionContainer"><div class="supporterPromotion"><a class="clearLink" href="http://emby.media/premiere" target="_blank"><button is="emby-button" type="button" class="raised block" style="text-transform:none;background-color:#52B54B;color:#fff;"><div>' + Globalize.translate('HeaderSupportTheTeam') + '</div><div style="font-weight:normal;margin-top:5px;">' + Globalize.translate('TextEnjoyBonusFeatures') + '</div></button></a></div></div>';
 
-                        $('.content-primary', page).append(html);
-                    }
+                    page.querySelector('.content-primary').insertAdjacentHTML('afterbegin', html);
                 }
-
-            });
-
+            }
         });
 
-    })();
-
+    });
 });
\ No newline at end of file
