@@ -1,19 +1,25 @@
-﻿define(['datetime', 'scrollStyles'], function (datetime) {
+﻿define(['datetime', 'cardBuilder', 'emby-itemscontainer', 'scrollStyles'], function (datetime, cardBuilder) {
+
+    function getUpcomingPromise() {
 
-    function loadUpcoming(page) {
         Dashboard.showLoadingMsg();
 
         var query = {
 
             Limit: 40,
-            Fields: "AirTime,UserData,SeriesStudio,SyncInfo",
+            Fields: "AirTime,UserData",
             UserId: Dashboard.getCurrentUserId(),
             ImageTypeLimit: 1,
             EnableImageTypes: "Primary,Backdrop,Banner,Thumb",
             EnableTotalRecordCount: false
         };
 
-        ApiClient.getJSON(ApiClient.getUrl("Shows/Upcoming", query)).then(function (result) {
+        return ApiClient.getJSON(ApiClient.getUrl("Shows/Upcoming", query));
+    }
+
+    function loadUpcoming(page, promise) {
+
+        promise.then(function (result) {
 
             var items = result.Items;
 
@@ -94,23 +100,23 @@
             html += '<h1 class="listHeader">' + group.name + '</h1>';
 
             if (enableScrollX()) {
-                html += '<div class="itemsContainer hiddenScrollX">';
+                html += '<div is="emby-itemscontainer" class="itemsContainer hiddenScrollX">';
             } else {
-                html += '<div class="itemsContainer">';
+                html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
             }
 
-            html += LibraryBrowser.getPosterViewHtml({
+            html += cardBuilder.getCardsHtml({
                 items: group.items,
                 showLocationTypeIndicator: false,
                 shape: getThumbShape(),
                 showTitle: true,
-                showPremiereDate: true,
                 preferThumb: true,
                 lazy: true,
                 showDetailsMenu: true,
                 centerText: true,
                 context: 'home-upcoming',
-                overlayMoreButton: true
+                overlayMoreButton: true,
+                showParentTitle: true
 
             });
             html += '</div>';
@@ -125,10 +131,16 @@
     return function (view, params, tabContent) {
 
         var self = this;
+        var upcomingPromise;
+
+        self.preRender = function () {
+            upcomingPromise = getUpcomingPromise();
+        };
 
         self.renderTab = function () {
 
-            loadUpcoming(tabContent);
+            Dashboard.showLoadingMsg();
+            loadUpcoming(view, upcomingPromise);
         };
     };
 
