@@ -1,4 +1,4 @@
-﻿define(['jQuery'], function ($) {
+﻿define(['datetime', 'jQuery'], function (datetime, $) {
 
     var currentItem;
 
@@ -52,7 +52,7 @@
             $('.time', page).html(Globalize.translate('LabelAnytime')).trigger('create');
         }
         else if (item.ChannelId) {
-            $('.time', page).html(LibraryBrowser.getDisplayTime(item.StartDate)).trigger('create');
+            $('.time', page).html(datetime.getDisplayTime(item.StartDate)).trigger('create');
         }
 
         Dashboard.hideLoadingMsg();
@@ -129,19 +129,6 @@
 
     }
 
-    function renderRecordings(page, result) {
-
-        $('.recordingsTab', page).html(LibraryBrowser.getPosterViewHtml({
-
-            items: result.Items,
-            shape: "detailPageSquare",
-            showTitle: true,
-            centerText: true,
-            coverImage: true
-
-        }));
-    }
-
     function renderSchedule(page, result) {
 
         var timers = result.Items;
@@ -172,17 +159,6 @@
 
         });
 
-        ApiClient.getLiveTvRecordings({
-
-            userId: Dashboard.getCurrentUserId(),
-            seriesTimerId: id
-
-        }).then(function (recordingResult) {
-
-            renderRecordings(page, recordingResult);
-
-        });
-
         ApiClient.getLiveTvTimers({
 
             seriesTimerId: id
